sqlobject.tests.test_declarative module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_declarative module

class `sqlobject.tests.test_declarative.` `A1`(*args, **kw)

  Bases: `sqlobject.declarative.Declarative`

  `a` = 1
  `b` = []
  `declarative_count` = 9

class `sqlobject.tests.test_declarative.` `A2`(*args, **kw)

  Bases: `sqlobject.tests.test_declarative.A1`

  `a` = 5
  `declarative_count` = 10

class `sqlobject.tests.test_declarative.` `B1`(*args, **kw)

  Bases: `sqlobject.declarative.Declarative`

  static `add_attrs`(old_attrs, new_attrs)
  `attrs` = ['c']
  `c` = 1
  `declarative_count` = 12

class `sqlobject.tests.test_declarative.` `B2`(*args, **kw)

  Bases: `sqlobject.tests.test_declarative.B1`

  `attrs` = ['c', 'g', 'test']
  `declarative_count` = 13
  `g` = 3

`sqlobject.tests.test_declarative.` `test_a_classes`()

`sqlobject.tests.test_declarative.` `test_b_classes`()